@@ -1,4 +1,4 @@
-char *loaders_rcs = "$Id: loaders.c,v 1.23 1998/01/23 13:42:09 ACJC Exp $";
+char *loaders_rcs = "$Id: loaders.c,v 1.24 1998/10/22 15:30:38 ACJC Exp $";
 /* Written and copyright 1997 Anonymous Coders and Junkbusters Corporation.
  * Distributed under the GNU General Public License; see the README file.
  * This code comes with NO WARRANTY. http://www.junkbusters.com/ht/en/gpl.html
@@ -228,14 +228,10 @@ load_blockfile(struct client_state *csp)
 		freez(p);
 		fs->proxy_args = strsav(fs->proxy_args, "<br>");
 
-		if((p = strpbrk(buf, "\r\n")) == NULL) {
-			errno = EINVAL;
-			fclose(fp);
-			goto load_blockfile_error;
+		if((p = strpbrk(buf, "\r\n")) != NULL) {
+			*p = '\0';
 		}
 
-		*p = '\0';
-
 		/* comments */
 		if((p = strchr(buf, '#'))) *p = '\0';
 
@@ -419,14 +415,10 @@ load_cookiefile(struct client_state *csp)
 		freez(p);
 		fs->proxy_args = strsav(fs->proxy_args, "<br>");
 
-		if((p = strpbrk(buf, "\r\n")) == NULL) {
-			errno = EINVAL;
-			fclose(fp);
-			goto load_cookie_error;
+		if((p = strpbrk(buf, "\r\n")) != NULL) {
+			*p = '\0';
 		}
 
-		*p = '\0';
-
 		/* comments */
 		if((p = strchr(buf, '#'))) *p = '\0';
 
@@ -635,14 +627,10 @@ load_trustfile(struct client_state *csp)
 		freez(p);
 		fs->proxy_args = strsav(fs->proxy_args, "<br>");
 
-		if((p = strpbrk(buf, "\r\n")) == NULL) {
-			errno = EINVAL;
-			fclose(fp);
-			goto load_trustfile_error;
+		if((p = strpbrk(buf, "\r\n")) != NULL) {
+			*p = '\0';
 		}
 
-		*p = '\0';
-
 		/* comments */
 		if((p = strchr(buf, '#'))) *p = '\0';
 
@@ -848,14 +836,10 @@ load_forwardfile(struct client_state *csp)
 		freez(p);
 		fs->proxy_args = strsav(fs->proxy_args, "<br>");
 
-		if((p = strpbrk(buf, "\r\n")) == NULL) {
-			errno = EINVAL;
-			fclose(fp);
-			goto load_forwardfile_error;
+		if((p = strpbrk(buf, "\r\n")) != NULL) {
+			*p = '\0';
 		}
 
-		*p = '\0';
-
 		/* comments */
 		if((p = strchr(buf, '#'))) *p = '\0';
 
